==> imx500_converter-3.14.3-py3-none-any.whl: imx500_converter/main_tf.py <==
# -------------------------------------------------------------------------------
# (c) Copyright 2024 Sony Semiconductor Israel, Ltd. All rights reserved.
#
#      This software, in source or object form (the "Software"), is the
#      property of Sony Semiconductor Israel Ltd. (the "Company") and/or its
#      licensors, which have all right, title and interest therein, You
#      may use the Software only in accordance with the terms of written
#      license agreement between you and the Company (the "License").
#      Except as expressly stated in the License, the Company grants no
#      licenses by implication, estoppel, or otherwise. If you are not
#      aware of or do not agree to the License terms, you may not use,
#      copy or modify the Software. You may use the source code of the
#      Software only for your internal purposes and may not distribute the
#      source code of the Software, any part thereof, or any derivative work
#      thereof, to any third party, except pursuant to the Company's prior
#      written consent.
#      The Software is the confidential information of the Company.
# -------------------------------------------------------------------------------
"""
Created on 7/7/24

@author: irenab
"""
from typing import Optional, List

from imx500_converter.converter.util.error import exit_on_uni_import_error
from imx500_converter import TF_EXTRA


def main(cli_args: Optional[List] = None):
    with exit_on_uni_import_error(TF_EXTRA):
        from uni.tensorflow.main import main

    from imx500_converter.converter.converter import convert
    return convert(uni_main=main, uni_exec='uni-tensorflow', cli_args=cli_args)


if __name__ == '__main__':
    import sys
    sys.exit(main())

==> imx500_converter-3.16.1-py3-none-any.whl: imx500_converter/main_tf.py <==
# -------------------------------------------------------------------------------
# (c) Copyright 2024 Sony Semiconductor Israel, Ltd. All rights reserved.
#
#      This software, in source or object form (the "Software"), is the
#      property of Sony Semiconductor Israel Ltd. (the "Company") and/or its
#      licensors, which have all right, title and interest therein, You
#      may use the Software only in accordance with the terms of written
#      license agreement between you and the Company (the "License").
#      Except as expressly stated in the License, the Company grants no
#      licenses by implication, estoppel, or otherwise. If you are not
#      aware of or do not agree to the License terms, you may not use,
#      copy or modify the Software. You may use the source code of the
#      Software only for your internal purposes and may not distribute the
#      source code of the Software, any part thereof, or any derivative work
#      thereof, to any third party, except pursuant to the Company's prior
#      written consent.
#      The Software is the confidential information of the Company.
# -------------------------------------------------------------------------------
"""
Created on 7/7/24

@author: irenab
"""
from typing import Optional, List

from imx500_converter.converter.util.error import exit_on_uni_import_error
from imx500_converter import TF_EXTRA


def main(cli_args: Optional[List] = None):
    with exit_on_uni_import_error(TF_EXTRA):
        from uni.tensorflow.main import main

    from imx500_converter.converter.converter import Converter
    return Converter(uni_main=main, uni_entry_point='uni-tensorflow')(cli_args=cli_args)


if __name__ == '__main__':
    import sys
    sys.exit(main())
